@@ -139,4 +139,4 @@ class Run:
         return resp["result"] == "success"
 
     def alert(self, title: str, level:str, message: str):
-        return interface.send_alert(run_id=self.run_id, team_name=self.team_name, exp_name=self.exp_name, run_name=self.run_name, title=title, msssage=message, level=level)
+        return interface.send_alert(run_id=self.run_id, team_name=self.team_name, exp_name=self.exp_name, run_name=self.run_name, title=title, message=message, level=level)
