@@ -7,7 +7,11 @@ import urllib3
 from deepdriver.sdk import util
 from deepdriver import logger
 import deepdriver.version as version
-URL_LOGIN = "/api/client/auth"
+from deepdriver.sdk.security.crypto import Aes
+
+URL_CHECK_EMAIL = "/api/public/login/email"
+URL_ID_LOGIN = "/api/public/login/pass"
+URL_API_LOGIN = "/api/client/auth"
 URL_CREATE = "/api/client/experiment/create"
 URL_CREATE_HPO = "/api/client/experiment/create/hpo"
 URL_GET_HPO = "/api/client/experiment/get/hpo"
@@ -48,16 +52,41 @@ def get_cert_path() -> str:
 
 # 서버의 login api 를 호출하여 API key 값을 서버로 전송하고 결과로서 jwt key 를 받는다.
 # 받은 jwt key 는 메모리에 저장해 두어서 추후 서버와 통신시 헤더에 실어서 보낼 수 있도록 한다.
-def login(http_host: str , api_key: str) -> Dict:
-    data = {
-        "key": api_key
-    }
+def login(http_host: str , api_key: str, id: str, pw: str) -> Dict:
 
-    url = parse_result_wraaper(http_host,URL_LOGIN)
-    rsp = post(url, data)
-    logger.debug("login() " + rsp["message"])
-    if rsp["result"] == "success":
-        set_jwt_key(rsp["token"])
+    if id!=None and pw!=None :
+        data = {
+            "email": id
+        }
+        url = parse_result_wraaper(http_host, URL_CHECK_EMAIL)
+        rsp = post(url, data)
+        if rsp["result"] == "success":
+            encKey = rsp["encKey"]
+            cipher= Aes(encKey)
+            encrypt_pw = cipher.aes_encrypt('pkcs5', pw, 'ECB',None)
+
+            url = parse_result_wraaper(http_host, URL_ID_LOGIN)
+            data = {
+                "email": id,
+                "password": encrypt_pw,
+                "signType": "NORMAL"
+            }
+            rsp = post(url, data)
+            logger.debug("login() " + rsp["message"])
+            if rsp["result"] == "success":
+                set_jwt_key(rsp["token"])
+            return rsp
+        else:
+            return rsp
+    else:
+        data = {
+            "key": api_key
+        }
+        url = parse_result_wraaper(http_host,URL_API_LOGIN)
+        rsp = post(url, data)
+        logger.debug("login() " + rsp["message"])
+        if rsp["result"] == "success":
+            set_jwt_key(rsp["token"])
     return rsp
 
 def init(http_host: str ,exp_name: str="", team_name: str="", run_name: str="", config: Dict=None) -> Dict:
@@ -67,12 +96,12 @@ def init(http_host: str ,exp_name: str="", team_name: str="", run_name: str="",
 
     # sysInfo값을 넘겨주어 rest api의 인자인 sysInfo필드에 넣어주도록 한다
     sys_info = {
-        "os": util.get_os(),
-        "python": util.get_python_version(),
-        "gpu": util.get_gpu(),
-        "gpuCount": util.get_gpu_count(),
-        "cpuCount": util.get_cpu_count(),
-        "hostname": util.get_hostname(),
+        "os": security.get_os(),
+        "python": security.get_python_version(),
+        "gpu": security.get_gpu(),
+        "gpuCount": security.get_gpu_count(),
+        "cpuCount": security.get_cpu_count(),
+        "hostname": security.get_hostname(),
     }
 
     # Interface.py의 init 함수 호출 후 응답받은 데이터로 부터 실험환경 이름과 팀이름, 실행이름, 실행ID, 대쉬보드URL을 가져와 Run 객체에 설정하고 반환한다.
@@ -80,7 +109,7 @@ def init(http_host: str ,exp_name: str="", team_name: str="", run_name: str="",
         "teamName": team_name,
         "expName": exp_name,
         "runName": run_name,
-        "config": {"cliVer": version.__version__, "pythonVer": util.get_python_version(), "_custom": _custom},
+        "config": {"cliVer": version.__version__, "pythonVer": security.get_python_version(), "_custom": _custom},
         "sysInfo": sys_info,
         "createRun": "Y",
     }
@@ -95,14 +124,14 @@ def create_hpo(http_host:str, exp_name: str="", team_name: str="", hpo_config: D
     data ={
         "teamName": team_name,
         "expName": exp_name,
-        "config":  {"cliVer": version.__version__, "pythonVer": util.get_python_version(), "hpoConfig": hpo_config},
+        "config":  {"cliVer": version.__version__, "pythonVer": security.get_python_version(), "hpoConfig": hpo_config},
         "sysInfo": {
-            "os": util.get_os(),
-            "python": util.get_python_version(),
-            "gpu": util.get_gpu(),
-            "gpuCount": util.get_gpu_count(),
-            "cpuCount": util.get_cpu_count(),
-            "hostname": util.get_hostname(),
+            "os": security.get_os(),
+            "python": security.get_python_version(),
+            "gpu": security.get_gpu(),
+            "gpuCount": security.get_gpu_count(),
+            "cpuCount": security.get_cpu_count(),
+            "hostname": security.get_hostname(),
         },
     }
     url = parse_result_wraaper(http_host,URL_CREATE_HPO)
